==> zonemaster-cli_6.0.3.orig.tar.gz: Zonemaster-CLI-v6.0.3/README.md <==
# Zonemaster-CLI


## Purpose

This Git repository is one of the components of the Zonemaster software and
contains the source for the Zonemaster-CLI utility.

For an overview of the Zonemaster software, please see the
[Zonemaster repository].


## Prerequisite

Before you install the Zonemaster-CLI utility, you need the Zonemaster-Engine
test framework installed. Please see the [Zonemaster Engine installation
instructions][Zonemaster-Engine installation].


## Installation

For installation, see the [installation] document.


## Configuration

This repository does not need any specific configuration.


## Docker

Zonemaster-CLI is available on [Docker Hub], and can be conveniently downloaded
and run without any installation. See [USING] Zonemaster-CLI for how to run
Zonemaster-CLI on Docker.

To build your own Docker image, see the [Docker Image Creation] documentation.


## Documentation

Other than the installation documentation, no specific documentation is needed.
The [USING] document provides an overview on how to use the CLI.


## Participation, Contact and Bug reporting

For participation, contact and bug reporting, please see the main
[Zonemaster README].


## License

This is free software under a 2-clause BSD license. The full text of the license can
be found in the [LICENSE](LICENSE) file included in this respository.


[Docker Image Creation]:             https://github.com/zonemaster/zonemaster/blob/master/docs/internal/maintenance/ReleaseProcess-create-docker-image.md
[Docker Hub]:                        https://hub.docker.com/u/zonemaster
[Installation]:                      https://github.com/zonemaster/zonemaster/blob/master/docs/public/installation/zonemaster-cli.md
[USING]:                             https://github.com/zonemaster/zonemaster/blob/master/docs/public/using/cli.md
[Zonemaster-Engine installation]:    https://github.com/zonemaster/zonemaster/blob/master/docs/public/installation/zonemaster-engine.md
[Zonemaster README]:                 https://github.com/zonemaster/zonemaster/blob/master/README.md
[Zonemaster repository]:             https://github.com/zonemaster/zonemaster

==> zonemaster-cli_8.0.0.orig.tar.gz: Zonemaster-CLI-v8.0.0/README.md <==
# Zonemaster-CLI


## Purpose

This Git repository is one of the components of the Zonemaster software and
contains the source for the Zonemaster-CLI utility.

For an overview of the Zonemaster software, please see the
[Zonemaster repository].


## Prerequisite

Before you install the Zonemaster-CLI utility, you need the Zonemaster-Engine
test framework installed. Please see the [Zonemaster Engine installation
instructions][Zonemaster-Engine installation].


## Installation

For installation, see the [installation] document.


## Configuration

This repository does not need any specific configuration.


## Docker

Zonemaster-CLI is available on [Docker Hub], and can be conveniently downloaded
and run without any installation. See [USING] Zonemaster-CLI for how to run
Zonemaster-CLI on Docker.

To build your own Docker image, see the [Docker Image Creation] documentation.


## Documentation

Run `zonemaster-cli --help` to get brief descriptions of a selection of the most
important command line options.
For complete reference documentation, see the manual page by running `man
zonemaster-cli`.
Additional end-user documentation is available in the [USING] document.

When developing Zonemaster-CLI, refer to the [development documentation].


## Participation, Contact and Bug reporting

For participation, contact and bug reporting, please see the main
[Zonemaster README].


## License

This is free software under a 2-clause BSD license. The full text of the license can
be found in the [LICENSE](LICENSE) file included in this respository.


[Development documentation]:         https://github.com/zonemaster/zonemaster/blob/master/docs/public/development/cli.md
[Docker Image Creation]:             https://github.com/zonemaster/zonemaster/blob/master/docs/internal/maintenance/ReleaseProcess-create-docker-image.md
[Docker Hub]:                        https://hub.docker.com/u/zonemaster
[Installation]:                      https://github.com/zonemaster/zonemaster/blob/master/docs/public/installation/zonemaster-cli.md
[USING]:                             https://github.com/zonemaster/zonemaster/blob/master/docs/public/using/cli.md
[Zonemaster-Engine installation]:    https://github.com/zonemaster/zonemaster/blob/master/docs/public/installation/zonemaster-engine.md
[Zonemaster README]:                 https://github.com/zonemaster/zonemaster/blob/master/README.md
[Zonemaster repository]:             https://github.com/zonemaster/zonemaster
